pub struct Explore {Show 13 fields
pub(super) header_bar: TemplateChild<HeaderBar>,
second_top_bar: TemplateChild<Bin>,
search_clamp: TemplateChild<Clamp>,
search_entry: TemplateChild<SearchEntry>,
servers_button: TemplateChild<MenuButton>,
servers_popover: TemplateChild<ExploreServersPopover>,
stack: TemplateChild<Stack>,
scrolled_window: TemplateChild<ScrolledWindow>,
listview: TemplateChild<ListView>,
session: WeakRef<Session>,
search: ExploreSearch,
end_items: OnceCell<SingleItemListModel>,
full_model: OnceCell<ListStore>,
}Fields
header_bar: TemplateChild<HeaderBar>second_top_bar: TemplateChild<Bin>search_clamp: TemplateChild<Clamp>search_entry: TemplateChild<SearchEntry>servers_popover: TemplateChild<ExploreServersPopover>stack: TemplateChild<Stack>scrolled_window: TemplateChild<ScrolledWindow>listview: TemplateChild<ListView>session: WeakRef<Session>The current session.
search: ExploreSearchThe search of the view.
end_items: OnceCell<SingleItemListModel>The items added at the end of the list.
full_model: OnceCell<ListStore>The full list model.
Implementations
Sourceimpl Explore
impl Explore
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl Explore
impl Explore
Sourcefn set_session(&self, session: Option<&Session>)
fn set_session(&self, session: Option<&Session>)
Set the current session.
Sourcefn end_items(&self) -> &SingleItemListModel
fn end_items(&self) -> &SingleItemListModel
The items added at the end of the list.
Sourcefn full_model(&self) -> &ListStore
fn full_model(&self) -> &ListStore
The full list model.
Sourcefn switch_to_narrow_mode(&self)
fn switch_to_narrow_mode(&self)
Update the header when the view is narrow.
Sourcefn switch_to_wide_mode(&self)
fn switch_to_wide_mode(&self)
Update the header when the view is wide.
Sourcefn update_visible_child(&self)
fn update_visible_child(&self)
Update the visible child according to the current state.
Sourcepub(super) fn trigger_search(&self)
pub(super) fn trigger_search(&self)
Trigger a search with the current term.
Sourcefn server_changed(&self)
fn server_changed(&self)
Handle when the selected server changed.